@@ -5,7 +5,6 @@ from grokcore.security import require
 
 from dolmen.content.interfaces import *
 from dolmen.content.directives import schema, factory, nofactory
-from dolmen.content.base import BaseContent, Content
-from dolmen.content.base import Container, OrderedContainer
+from dolmen.content.base import Content, Container, OrderedContainer
 from dolmen.content.utils import get_content_type
 from dolmen.content.factoring import Factory
