@@ -8,20 +8,16 @@ Herited schemas example
 
   >>> dolmen.schema.bind().get(gilgamesh)
   [<InterfaceClass ...IMythologicalHero>]
-
-The base properties must be inherited, thanks to the schema applier::
-
-  >>> MesopotamianGod.title
-  <zope.dublincore.property.DCProperty object at ...>
   
 """
 import dolmen.content as dolmen
-from zope.schema import TextLine
 from grokcore.component import baseclass
 from grokcore.content import Container
+from zope.interface import Interface
+from zope.schema import TextLine
 
 
-class IMythologicalHero(dolmen.IBaseContent):
+class IMythologicalHero(Interface):
     """A hero that transcended History.
     """
     homecity = TextLine(
